==> dcl-5.2C.tar.gz: dcl-5.2C/demo/grph2/umpack/umpk02.c <==
/* umpk02.f -- translated by f2c (version 19990503).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "f2c.h"

/* Table of constant values */

static integer c__9 = 9;
static integer c__1 = 1;
static integer c__3 = 3;
static real c_b6 = 2.f;
static real c_b7 = 3.f;
static integer c__2 = 2;
static real c_b16 = .1f;
static real c_b17 = .9f;
static logical c_true = TRUE_;
static real c_b24 = .5f;
static real c_b25 = .95f;
static real c_b26 = .03f;
static integer c__0 = 0;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Main program */ MAIN__(void)
{
    /* Initialized data */

    static integer ntr[14] = { 10,11,12,13,14,15,20,21,22,23,30,31,32,33 };

    /* System generated locals */
    integer i__1;

    /* Builtin functions */
    integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
	    e_wsle(void), s_rsle(cilist *), e_rsle(void);

    /* Local variables */
    static char cttl[32];
    static integer i__;
    extern /* Subroutine */ int grcls_(void), grfrm_(void), sldiv_(char *, 
	    integer *, integer *, ftnlen), gropn_(integer *), slrat_(real *, 
	    real *), umpglb_(void), umpmap_(char *, ftnlen), sglset_(char *, 
	    logical *, ftnlen), umpfit_(void), umiset_(char *, integer *, 
	    ftnlen), grstrf_(void), sgtrnl_(integer *, char *, ftnlen), 
	    grstrn_(integer *), sgpwsn_(void), grsvpt_(real *, real *, real *,
	     real *), slpvpr_(integer *), slpwwr_(integer *), sgtxzr_(real *, 
	    real *, char *, real *, integer *, integer *, integer *, ftnlen);
    static integer iws;

    /* Fortran I/O blocks */
    static cilist io___2 = { 0, 6, 0, 0, 0 };
    static cilist io___3 = { 0, 5, 0, 0, 0 };


    s_wsle(&io___2);
    do_lio(&c__9, &c__1, " WORKSTATION IS (I) ? ;", (ftnlen)23);
    e_wsle();
    sgpwsn_();
    s_rsle(&io___3);
    do_lio(&c__3, &c__1, (char *)&iws, (ftnlen)sizeof(integer));
    e_rsle();
    i__1 = -abs(iws);
    gropn_(&i__1);
    slrat_(&c_b6, &c_b7);
    sldiv_("Y", &c__2, &c__3, (ftnlen)1);
    umiset_("INDEXMJ", &c__1, (ftnlen)7);
    umiset_("ITYPEMN", &c__1, (ftnlen)7);
    for (i__ = 1; i__ <= 14; ++i__) {
	grfrm_();
/*       CALL GRSMPL( 0.0, 90.0, 0.0 ) */
	grsvpt_(&c_b16, &c_b17, &c_b16, &c_b17);
	grstrn_(&ntr[i__ - 1]);
	umpfit_();
	grstrf_();
	sglset_("LCLIP", &c_true, (ftnlen)5);
	slpwwr_(&c__1);
	slpvpr_(&c__1);
	sgtrnl_(&ntr[i__ - 1], cttl, (ftnlen)32);
	sgtxzr_(&c_b24, &c_b25, cttl, &c_b26, &c__0, &c__0, &c__3, (ftnlen)32)
		;
	umpmap_("coast_world", (ftnlen)11);
	umpglb_();
	if (ntr[i__ - 1] == 23) {
	    grfrm_();
	    grfrm_();
	}
/* L10: */
    }
    grcls_();
    return 0;
} /* MAIN__ */

/* Main program alias */ int umpk02_ () { MAIN__ (); return 0; }

==> dcl-6.0.2-C.tar.gz: dcl-6.0.2-C/demo/grph2/umpack/umpk02.c <==
/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__9 = 9;
static integer c__1 = 1;
static integer c__3 = 3;
static real c_b6 = 2.f;
static real c_b7 = 3.f;
static integer c__2 = 2;
static real c_b16 = .1f;
static real c_b17 = .9f;
static logical c_true = TRUE_;
static real c_b24 = .5f;
static real c_b25 = .95f;
static real c_b26 = .03f;
static integer c__0 = 0;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Main program */ int MAIN__(void)
{
    /* Initialized data */

    static integer ntr[14] = { 10,11,12,13,14,15,20,21,22,23,30,31,32,33 };

    /* System generated locals */
    integer i__1;

    /* Builtin functions */
    integer s_wsle(cilist *), do_lio(integer *, integer *, char *, ftnlen), 
	    e_wsle(void), s_rsle(cilist *), e_rsle(void);

    /* Local variables */
    static integer i__, iws;
    static char cttl[32];
    extern /* Subroutine */ int grcls_(void), grfrm_(void), sldiv_(char *, 
	    integer *, integer *, ftnlen), gropn_(integer *), slrat_(real *, 
	    real *), umpglb_(void), umpmap_(char *, ftnlen), sglset_(char *, 
	    logical *, ftnlen), umpfit_(void), umiset_(char *, integer *, 
	    ftnlen), grstrf_(void), sgtrnl_(integer *, char *, ftnlen), 
	    grstrn_(integer *), sgpwsn_(void), grsvpt_(real *, real *, real *,
	     real *), slpvpr_(integer *), slpwwr_(integer *), sgtxzr_(real *, 
	    real *, char *, real *, integer *, integer *, integer *, ftnlen);

    /* Fortran I/O blocks */
    static cilist io___2 = { 0, 6, 0, 0, 0 };
    static cilist io___3 = { 0, 5, 0, 0, 0 };


    s_wsle(&io___2);
    do_lio(&c__9, &c__1, " WORKSTATION IS (I) ? ;", (ftnlen)23);
    e_wsle();
    sgpwsn_();
    s_rsle(&io___3);
    do_lio(&c__3, &c__1, (char *)&iws, (ftnlen)sizeof(integer));
    e_rsle();
    i__1 = -abs(iws);
    gropn_(&i__1);
    slrat_(&c_b6, &c_b7);
    sldiv_("Y", &c__2, &c__3, (ftnlen)1);
    umiset_("INDEXMJ", &c__1, (ftnlen)7);
    umiset_("ITYPEMN", &c__1, (ftnlen)7);
    for (i__ = 1; i__ <= 14; ++i__) {
	grfrm_();
/*       CALL GRSMPL( 0.0, 90.0, 0.0 ) */
	grsvpt_(&c_b16, &c_b17, &c_b16, &c_b17);
	grstrn_(&ntr[i__ - 1]);
	umpfit_();
	grstrf_();
	sglset_("LCLIP", &c_true, (ftnlen)5);
	slpwwr_(&c__1);
	slpvpr_(&c__1);
	sgtrnl_(&ntr[i__ - 1], cttl, (ftnlen)32);
	sgtxzr_(&c_b24, &c_b25, cttl, &c_b26, &c__0, &c__0, &c__3, (ftnlen)32)
		;
	umpmap_("coast_world", (ftnlen)11);
	umpglb_();
	if (ntr[i__ - 1] == 23) {
	    grfrm_();
	    grfrm_();
	}
/* L10: */
    }
    grcls_();
    return 0;
} /* MAIN__ */

/* Main program alias */ int umpk02_ () { MAIN__ (); return 0; }
